# testdata/sbdb

This contains sample responses from the JPL Small Bodies Database, retrieved February 21-22 2023.

The URLs queried were:

- https://ssd-api.jpl.nasa.gov/sbdb.api?sstr=2001VB&cov=mat&full-prec=true
- https://ssd-api.jpl.nasa.gov/sbdb.api?sstr=443104&cov=mat&full-prec=true
- https://ssd-api.jpl.nasa.gov/sbdb.api?sstr=54509&cov=mat&full-prec=true
- https://ssd-api.jpl.nasa.gov/sbdb.api?sstr=missingno&cov=mat&full-prec=true
